@@ -11,6 +11,7 @@ generation logic for the config YAML file.
 
 from __future__ import division, print_function, unicode_literals
 
+import contextlib
 import distro
 from collections import defaultdict
 from itertools import count
@@ -26,7 +27,7 @@ import warnings
 from reprozip import __version__ as reprozip_version
 from reprozip import _pytracer
 from reprozip.common import File, InputOutputFile, load_config, save_config, \
-    FILE_READ, FILE_WRITE, FILE_LINK
+    FILE_READ, FILE_WRITE, FILE_LINK, FILE_SOCKET
 from reprozip.tracer.linux_pkgs import magic_dirs, system_dirs, \
     identify_packages
 from reprozip.utils import PY3, izip, iteritems, itervalues, \
@@ -36,6 +37,21 @@ from reprozip.utils import PY3, izip, iteritems, itervalues, \
 logger = logging.getLogger('reprozip')
 
 
+systemd_sockets = ('/run/systemd/private', '/run/dbus/system_bus_socket')
+
+
+@contextlib.contextmanager
+def stderr_in_red():
+    if os.isatty(sys.stderr.fileno()):
+        try:
+            print('\x1b[31;20m', file=sys.stderr, end='', flush=True)
+            yield
+        finally:
+            print('\x1b[0m', file=sys.stderr, end='', flush=True)
+    else:
+        yield
+
+
 class TracedFile(File):
     """Override of `~reprozip.common.File` that reads stats from filesystem.
 
@@ -145,6 +161,7 @@ def get_files(conn):
         ORDER BY timestamp;
         ''')
     executed = set()
+    systemd_accessed = False
     run = 0
     for event_type, r_name, r_mode, r_timestamp in rows:
         if event_type == 'exec':
@@ -178,6 +195,9 @@ def get_files(conn):
             f = files[r_name]
         if r_mode & FILE_READ:
             f.read(run)
+        if r_mode & FILE_SOCKET:
+            if r_name in systemd_sockets:
+                systemd_accessed = True
         if r_mode & FILE_WRITE:
             f.write(run)
             # Mark the parent directory as read
@@ -230,21 +250,31 @@ def get_files(conn):
     inputs = [[path for path in lst if path in files]
               for lst in inputs]
 
-    # Displays a warning for READ_THEN_WRITTEN files
+    # Display a warning for READ_THEN_WRITTEN files
     read_then_written_files = [
         fi
         for fi in itervalues(files)
         if fi.what == TracedFile.READ_THEN_WRITTEN and
         not any(fi.path.lies_under(m) for m in magic_dirs)]
     if read_then_written_files:
-        logger.warning(
-            "Some files were read and then written. We will only pack the "
-            "final version of the file; reproducible experiments shouldn't "
-            "change their input files")
+        with stderr_in_red():
+            logger.warning(
+                "Some files were read and then written. We will only pack the "
+                "final version of the file; reproducible experiments "
+                "shouldn't change their input files")
         logger.info("Paths:\n%s",
                     ", ".join(unicode_(fi.path)
                               for fi in read_then_written_files))
 
+    # Display a warning for systemd
+    if systemd_accessed:
+        with stderr_in_red():
+            logger.warning(
+                "A connection to systemd was detected. If systemd was asked "
+                "to start a process, it won't be captured by reprozip, "
+                "because it is an independent server. Please see "
+                "https://docs.reprozip.org/s/systemd for more information")
+
     files = set(
         fi
         for fi in itervalues(files)
@@ -328,9 +358,10 @@ def trace(binary, argv, directory, append, verbosity='unset'):
         if append is None:
             r = tty_prompt(
                 "Trace directory %s exists\n"
-                "(a)ppend run to the trace, (d)elete it or (s)top? [a/d/s] " %
+                "(a)ppend run to the trace, (o)verwrite it, "
+                "or (s)top? [a/o/s] " %
                 directory,
-                'aAdDsS')
+                'aAdDoOsS')
             if r is None:
                 logger.critical(
                     "Trace directory %s exists\n"
@@ -339,7 +370,7 @@ def trace(binary, argv, directory, append, verbosity='unset'):
                 sys.exit(125)
             elif r in 'sS':
                 sys.exit(125)
-            elif r in 'dD':
+            elif r in 'oOdD':  # keep accepting 'd' for delete
                 directory.rmtree()
                 directory.mkdir()
             logger.warning(
