@@ -1,4 +1,4 @@
-# Copyright (C) 2014-2017 New York University
+# Copyright (C) 2014 New York University
 # This file is part of ReproZip which is released under the Revised BSD License
 # See file LICENSE for full license details.
 
@@ -68,8 +68,9 @@ if PY3:
     itervalues = lambda d: d.values()
     listvalues = lambda d: list(d.values())
 
-    stdout_bytes, stderr_bytes = sys.stdout.buffer, sys.stderr.buffer
-    stdin_bytes = sys.stdin.buffer
+    stdout_bytes = sys.stdout.buffer if sys.stdout is not None else None
+    stderr_bytes = sys.stderr.buffer if sys.stderr is not None else None
+    stdin_bytes = sys.stdin.buffer if sys.stdin is not None else None
     stdout, stderr = sys.stdout, sys.stderr
 else:
     izip = itertools.izip
@@ -140,17 +141,6 @@ def escape(s):
     return s.replace('\\', '\\\\').replace('"', '\\"')
 
 
-class CommonEqualityMixin(object):
-    """Common mixin providing comparison by comparing ``__dict__`` attributes.
-    """
-    def __eq__(self, other):
-        return (isinstance(other, self.__class__) and
-                self.__dict__ == other.__dict__)
-
-    def __ne__(self, other):
-        return not self.__eq__(other)
-
-
 def optional_return_type(req_args, other_args):
     """Sort of namedtuple but with name-only fields.
 
